@@ -31,6 +31,7 @@ class Task:
     project = None
     code_id = None
     code_history_id = None
+    schedule_id = None
     status = None
     code_name = None
     code_rev = None
@@ -237,7 +238,10 @@ class CodePackage:
 
 class IronWorker:
     NAME = "iron_worker_python"
-    VERSION = "1.2.0"
+    VERSION = "1.3.5"
+    
+    isLoaded = False
+    arguments = {'task_id': None, 'dir': None, 'payload': None, 'config': None}
 
     def __init__(self, **kwargs):
         """Prepare a configured instance of the API wrapper and return it.
@@ -245,7 +249,7 @@ class IronWorker:
         Keyword arguments are passed directly to iron_core_python; consult its
         documentation for a full list and possible values."""
         self.client = iron_core.IronClient(name=IronWorker.NAME,
-                version=IronWorker.VERSION, product="iron_worker", **kwargs)
+                version=IronWorker.VERSION, product="iron_worker", **kwargs)    
 
     #############################################################
     ####################### CODE PACKAGES #######################
@@ -365,19 +369,23 @@ class IronWorker:
     #############################################################
     ########################## TASKS ############################
     #############################################################
-    def tasks(self, scheduled=False):
-        tasks = []
+    def tasks(self, scheduled=False, page=None, per_page=30):
         if not scheduled:
             resp = self.client.get("tasks")
             raw_tasks = resp["body"]
             raw_tasks = raw_tasks["tasks"]
         else:
-            resp = self.client.get("schedules")
+            if per_page > 100:
+                raise Exception("The limit for per_page is 100")
+            query_params = "?per_page=" + str(per_page)
+            if page is not None:
+                query_params += "&page=" + page
+            request_string = "schedules" + query_params
+            resp = self.client.get(request_string)
             raw_tasks = resp["body"]
             raw_tasks = raw_tasks["schedules"]
 
-        for raw_task in raw_tasks:
-            tasks.append(Task(raw_task))
+        tasks = [Task(raw_task) for raw_task in raw_tasks]
         return tasks
 
     def tasks_by_code_name(self, code_name):
@@ -432,6 +440,8 @@ class IronWorker:
                         task.start_at = task.start_at.replace(tzinfo=tzlocal())
                     task_data["start_at"] = iron_core.IronClient.toRfc3339(
                             task.start_at)
+                if task.timeout is not None:
+                    task_data["timeout"] = task.timeout
                 task_data["label"] = task.label
                 task_data["cluster"] = task.cluster
             tasks_data.append(task_data)
@@ -543,3 +553,71 @@ class IronWorker:
     @staticmethod
     def get_content_type(filename):
         return mimetypes.guess_type(filename)[0] or 'application/octet-stream'
+
+    @staticmethod
+    def load_args():
+        if IronWorker.isLoaded: return
+
+        for i in range(len(sys.argv)):
+            if sys.argv[i] == "-id":
+                IronWorker.arguments['task_id'] = sys.argv[i + 1]
+            if sys.argv[i] == "-d":
+                IronWorker.arguments['dir'] = sys.argv[i + 1]
+            if sys.argv[i] == "-payload":
+                IronWorker.arguments['payload_file'] = sys.argv[i + 1]
+            if sys.argv[i] == "-config":
+                IronWorker.arguments['config_file'] = sys.argv[i + 1]
+        
+        if os.getenv('TASK_ID'): IronWorker.arguments['task_id'] = os.getenv('TASK_ID')
+        if os.getenv('TASK_DIR'): IronWorker.arguments['dir'] = os.getenv('TASK_DIR')
+        if os.getenv('PAYLOAD_FILE'): IronWorker.arguments['payload_file'] = os.getenv('PAYLOAD_FILE')
+        if os.getenv('CONFIG_FILE'): IronWorker.arguments['config_file'] = os.getenv('CONFIG_FILE')
+
+        if 'payload_file' in IronWorker.arguments and file_exists(IronWorker.arguments['payload_file']):
+	    f = open(IronWorker.arguments['payload_file'], "r")
+            try:
+                content = f.read()
+                f.close()
+                IronWorker.arguments['payload'] = json.loads(content)
+            except Exception, e:
+                print "Couldn't parse IronWorker payload into json, leaving as string. %s" % e
+
+        if 'config_file' in IronWorker.arguments and file_exists(IronWorker.arguments['config_file']):
+            f = open(IronWorker.arguments['config_file'])
+            try:
+                content = f.read()
+                f.close()
+                IronWorker.arguments['config'] = json.loads(content)
+            except Exception, e:
+                print "Couldn't parse IronWorker config into json. %s" % e
+
+        IronWorker.isLoaded = True
+
+    @staticmethod
+    def payload():
+        IronWorker.load_args()
+        return IronWorker.arguments['payload']
+    
+    @staticmethod
+    def config():
+        IronWorker.load_args()
+        return IronWorker.arguments['config']
+
+    @staticmethod
+    def task_id():
+        IronWorker.load_args()
+        return IronWorker.arguments['task_id']
+
+    @staticmethod
+    def task_dir():
+        IronWorker.load_args()
+        return IronWorker.arguments['dir']
+
+    @staticmethod
+    def args():
+        IronWorker.load_args()
+        return IronWorker.arguments
+
+    @staticmethod
+    def loaded():
+        return IronWorker.isLoaded
